def 文本_取文本最后出现的位置(文本, 查找的文本):
    """
    返回指定文本中指定子串最后一次出现的位置。

    参数：
    文本 (str): 要搜索的文本。
    查找的文本 (str): 要查找的文本。

    返回值：
    int: 最后一次出现的位置索引，如果没有找到或者出现异常则返回-1。
    """
    try:
        # 使用rfind函数查找子串最后一次出现的位置
        最后位置 = 文本.rfind(查找的文本)
        return 最后位置
    except Exception:
        return -1