def 列表_交集(列表1, 列表2):
    """
    返回两个列表的交集(两个列表都有的元素，就叫交集)。

    参数:
        - 列表1 (list): 第一个列表。
        - 列表2 (list): 第二个列表。

    返回:
        - list: 包含两个列表中共同元素的列表。如果出现异常，返回空列表。
    """
    try:
        # 使用集合求交集，然后转换回列表
        交集结果 = list(set(列表1) & set(列表2))
        return 交集结果
    except Exception:
        return []