国家代码_中国 = "CN"  # 中国
国家代码_美国 = "US"  # 美国
国家代码_日本 = "JP"  # 日本
国家代码_德国 = "DE"  # 德国
国家代码_法国 = "FR"  # 法国
国家代码_英国 = "GB"  # 英国
国家代码_印度 = "IN"  # 印度
国家代码_意大利 = "IT"  # 意大利
国家代码_巴西 = "BR"  # 巴西
国家代码_俄罗斯 = "RU"  # 俄罗斯
国家代码_加拿大 = "CA"  # 加拿大
国家代码_澳大利亚 = "AU"  # 澳大利亚
国家代码_韩国 = "KR"  # 韩国
国家代码_墨西哥 = "MX"  # 墨西哥
国家代码_西班牙 = "ES"  # 西班牙
国家代码_南非 = "ZA"  # 南非
国家代码_新加坡 = "SG"  # 新加坡
国家代码_荷兰 = "NL"  # 荷兰
国家代码_瑞士 = "CH"  # 瑞士
国家代码_瑞典 = "SE"  # 瑞典
国家代码_阿根廷 = "AR"  # 阿根廷
国家代码_比利时 = "BE"  # 比利时
国家代码_智利 = "CL"  # 智利
国家代码_丹麦 = "DK"  # 丹麦
国家代码_芬兰 = "FI"  # 芬兰
国家代码_希腊 = "GR"  # 希腊
国家代码_匈牙利 = "HU"  # 匈牙利
国家代码_爱尔兰 = "IE"  # 爱尔兰
国家代码_以色列 = "IL"  # 以色列
国家代码_马来西亚 = "MY"  # 马来西亚
国家代码_挪威 = "NO"  # 挪威
国家代码_新西兰 = "NZ"  # 新西兰
国家代码_菲律宾 = "PH"  # 菲律宾
国家代码_波兰 = "PL"  # 波兰
国家代码_葡萄牙 = "PT"  # 葡萄牙
国家代码_罗马尼亚 = "RO"  # 罗马尼亚
国家代码_沙特阿拉伯 = "SA"  # 沙特阿拉伯
国家代码_泰国 = "TH"  # 泰国
国家代码_土耳其 = "TR"  # 土耳其
国家代码_阿联酋 = "AE"  # 阿联酋
国家代码_乌克兰 = "UA"  # 乌克兰
国家代码_越南 = "VN"  # 越南
国家代码_阿富汗 = "AF"  # 阿富汗
国家代码_阿尔巴尼亚 = "AL"  # 阿尔巴尼亚
国家代码_阿尔及利亚 = "DZ"  # 阿尔及利亚
国家代码_安道尔 = "AD"  # 安道尔
国家代码_安哥拉 = "AO"  # 安哥拉
国家代码_安提瓜和巴布达 = "AG"  # 安提瓜和巴布达
国家代码_亚美尼亚 = "AM"  # 亚美尼亚
国家代码_阿塞拜疆 = "AZ"  # 阿塞拜疆
国家代码_巴哈马 = "BS"  # 巴哈马
国家代码_巴林 = "BH"  # 巴林
国家代码_孟加拉国 = "BD"  # 孟加拉国
国家代码_巴巴多斯 = "BB"  # 巴巴多斯
国家代码_白俄罗斯 = "BY"  # 白俄罗斯
国家代码_伯利兹 = "BZ"  # 伯利兹
国家代码_贝宁 = "BJ"  # 贝宁
国家代码_不丹 = "BT"  # 不丹
国家代码_玻利维亚 = "BO"  # 玻利维亚
国家代码_波斯尼亚和黑塞哥维那 = "BA"  # 波斯尼亚和黑塞哥维那
国家代码_博茨瓦纳 = "BW"  # 博茨瓦纳
国家代码_文莱 = "BN"  # 文莱
国家代码_保加利亚 = "BG"  # 保加利亚
国家代码_布基纳法索 = "BF"  # 布基纳法索
国家代码_布隆迪 = "BI"  # 布隆迪
