def excel_删除列(表格对象, 工作表名, 列号, 列数=1):
    """
    参数:
    - 表格对象: 要操作的表格对象
    - 工作表名: 要删除列的工作表名称
    - 列号: 要删除列的位置
    - 列数: 要删除的列数，默认为1

    返回值:
    - 如果成功删除列，则返回 True；如果删除失败，则返回 False
    """
    try:
        # 获取指定的工作表
        工作表 = 表格对象[工作表名]
        # 删除指定列数
        工作表.delete_cols(列号, 列数)
        return True
    except Exception:
        return False