def 文本_去除指定字符串_自定义位置(原始文本: str, 目标文本: str, 出现次数: int):
    """
    去除原始文本中目标文本的第几次出现。

    参数:
        - 原始文本(str): 原始的文本内容。
        - 目标文本(str): 需要去除的字符或字符串。
        - 出现次数(int): 需要去除的是第几次出现。

    返回:
        处理后的文本。如果次数不足或出现异常则返回原始文本
    """
    try:
        位置 = -1

        # 找到目标文本的第几次出现位置
        for i in range(出现次数):
            位置 = 原始文本.find(目标文本, 位置 + 1)
            if 位置 == -1:
                # 如果目标文本出现的次数不足，返回原始文本
                return 原始文本

        # 去除目标文本的第几次出现
        if 位置 != -1:
            return 原始文本[:位置] + 原始文本[位置 + len(目标文本):]
        return 原始文本
    except Exception:
        return 原始文本